@@ -213,6 +213,7 @@ def load_table(
     datetime_format = '%Y-%m-%d %H:%M:%S', 
     check_columns = True,
     flush_cache = True,
+    hard_assert = False,
 ):
     """
     Load table and convert column types
@@ -222,6 +223,14 @@ def load_table(
     df = gbq.download_table_to_pandas(dataset_table, flush_cache=flush_cache)
 
     if df is None:
+        if hard_assert:
+            assert df is not None, "  Could not load '{}".format(dataset_table)
+        else:
+            warnings.warn(
+                "  Could not load '{}".format(dataset_table),
+                category=UserWarning, 
+                stacklevel=1
+            )
         return None
     
     print("[load_table] Converting table columns...")
@@ -264,7 +273,8 @@ def load_csv(
     datetime_columns = None,
     datetime_format='%Y-%m-%d %H:%M:%S',
     check_columns=True,
-    flush_cache = True
+    flush_cache = True,
+    hard_assert = False,
 ):
     """
     Load CSV from GCS and convert column types.
@@ -274,6 +284,14 @@ def load_csv(
     df = gcs.download_csv(filename, flush_cache=flush_cache)
     
     if df is None:
+        if hard_assert:
+            assert df is not None, "  Could not load '{}".format(filename)
+        else:
+            warnings.warn(
+                "  Could not load '{}".format(filename),
+                category=UserWarning, 
+                stacklevel=1
+            )
         return None
     
     print("[load_table] Converting table columns...")
@@ -319,6 +337,7 @@ def load_and_merge_tables(
     check_columns = True,
     keep_most_recent_trans_id=True,
     flush_cache = True,
+    hard_assert = False,
 ):
     """
     1. Load tables by date range. 
@@ -336,20 +355,38 @@ def load_and_merge_tables(
             else:
                 table = "{}.{}_{}".format(dataset, table_type, date_range)
 
-            df_tmp = gbq.download_table_to_pandas(
+            df_in = gbq.download_table_to_pandas(
                 table,
                 flush_cache=flush_cache
             )
-            if df_tmp is not None:
+            if df_in is not None:
                 if df is None:
-                    df = df_tmp.copy()
+                    df = df_in.copy()
                 else:
-                    df = df.append(df_tmp, sort=True, ignore_index=True)
+                    df = df.append(df_in, sort=True, ignore_index=True)
+            else:
+                if hard_assert:
+                    assert df_in is not None, "  Could not load '{}".format(table)
+                else:
+                    warnings.warn(
+                        "  Could not load '{}".format(table),
+                        category=UserWarning, 
+                        stacklevel=1
+                    )
     else:
-        df = gbq.download_table_to_pandas("{}.{}".format(dataset, table_name))
+        table = "{}.{}".format(dataset, table_name)
+        df = gbq.download_table_to_pandas(table)
 
-    if df is None:
-        return None
+        if df is None:
+            if hard_assert:
+                assert df is not None, "  Could not load '{}".format(table)
+            else:
+                warnings.warn(
+                    "  Could not load '{}".format(table),
+                    category=UserWarning, 
+                    stacklevel=1
+                )
+            return None
     
     do_continue = True
     if check_columns:
